@@ -1,6 +1,6 @@
 package Devel::StackTrace;
 {
-  $Devel::StackTrace::VERSION = '1.28';
+  $Devel::StackTrace::VERSION = '1.29';
 }
 
 use 5.006;
@@ -200,7 +200,16 @@ sub reset_pointer {
 sub frames {
     my $self = shift;
 
-    $self->_make_frames() if $self->{raw};
+    if (@_) {
+        die
+            "Devel::StackTrace->frames() can only take Devel::StackTrace::Frame args\n"
+            if grep { !$_->isa('Devel::StackTrace::Frame') } @_;
+
+        $self->{frames} = \@_;
+    }
+    else {
+        $self->_make_frames() if $self->{raw};
+    }
 
     return @{ $self->{frames} };
 }
@@ -255,7 +264,7 @@ Devel::StackTrace - An object representing a stack trace
 
 =head1 VERSION
 
-version 1.28
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -417,8 +426,17 @@ appropriate.
 
 =item * $trace->frames
 
-Returns a list of Devel::StackTrace::Frame objects.  The order they are
-returned is from top (most recent) to bottom.
+When this method is called with no arguments, it returns a list of
+L<Devel::StackTrace::Frame> objects. They are returned in order from top (most
+recent) to bottom.
+
+This method can also be used to set the object's frames if you pass it a list
+of L<Devel::StackTrace::Frame> objects objects.
+
+This is useful if you want to filter the list of frames in ways that are more
+complex than can be handled by C<filter_frames>:
+
+  $stacktrace->frames( my_filter( $stacktrace->frames() ) );
 
 =item * $trace->frame ($index)
 
